@@ -1,6 +1,7 @@
 package Reddit::Client;
 
-our $VERSION = '1.099';  
+our $VERSION = '1.0991';
+# 1.0991: there was a debug message and get_permalink was broken  
 # 1.099:
 #  -updated get_user and list_subreddits to use set_listing_defaults
 #  -get_user can now accept the 'about' view
@@ -281,6 +282,7 @@ sub get_token {
 	$self->{last_token} 	= time;
 
 	my $message = Reddit::Client::Request->token_request($self->{client_id}, $self->{secret}, $self->{username}, $self->{password}, $self->{user_agent});
+	#dd $message;
 	my $j = JSON::decode_json($message);
 	$self->{token} 		= $j->{access_token};
 	$self->{tokentype} 	= $j->{token_type};
@@ -543,7 +545,6 @@ sub search {
 sub get_permalink {
 	# This still makes an extra request. Why?
 	my ($self, $commentid, $post_fullname) = @_;
-	return "wtf in Client";
 
 	if (substr ($commentid, 0, 3) eq "t1_") { $commentid = substr $commentid, 3; } 
 	if (substr ($post_fullname, 0, 3) ne "t3_") { $post_fullname = "t3_" . $post_fullname; } 
